@@ -27,8 +27,6 @@
 
 #include <telepathy-glib/telepathy-glib.h>
 
-#include <telepathy-yell/telepathy-yell.h>
-
 #include "empathy-call-utils.h"
 
 #include <libempathy/empathy-gsettings.h>
@@ -85,14 +83,14 @@ empathy_call_create_call_request (const gchar *contact,
 {
   return tp_asv_new (
     TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING,
-      TPY_IFACE_CHANNEL_TYPE_CALL,
+      TP_IFACE_CHANNEL_TYPE_CALL,
     TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT,
       TP_HANDLE_TYPE_CONTACT,
     TP_PROP_CHANNEL_TARGET_ID, G_TYPE_STRING,
       contact,
-    TPY_PROP_CHANNEL_TYPE_CALL_INITIAL_AUDIO, G_TYPE_BOOLEAN,
+    TP_PROP_CHANNEL_TYPE_CALL_INITIAL_AUDIO, G_TYPE_BOOLEAN,
       initial_audio,
-    TPY_PROP_CHANNEL_TYPE_CALL_INITIAL_VIDEO, G_TYPE_BOOLEAN,
+    TP_PROP_CHANNEL_TYPE_CALL_INITIAL_VIDEO, G_TYPE_BOOLEAN,
       initial_video,
     NULL);
 }
@@ -134,7 +132,6 @@ create_streamed_media_channel_cb (GObject *source,
     }
 }
 
-#ifdef HAVE_CALL
 static void
 create_call_channel_cb (GObject *source,
     GAsyncResult *result,
@@ -146,24 +143,24 @@ create_call_channel_cb (GObject *source,
   if (tp_account_channel_request_create_channel_finish (
       TP_ACCOUNT_CHANNEL_REQUEST (source), result, &error))
     {
-      g_object_unref (streamed_media_req);
+      g_clear_object (&streamed_media_req);
       return;
     }
 
   DEBUG ("Failed to create Call channel: %s", error->message);
 
-  if (error->code != TP_ERROR_NOT_IMPLEMENTED)
+  if (streamed_media_req != NULL)
     {
-      show_call_error (error);
+      DEBUG ("Let's try with an StreamedMedia channel");
+      g_error_free (error);
+      tp_account_channel_request_create_channel_async (streamed_media_req,
+          EMPATHY_AV_BUS_NAME, NULL,
+          create_streamed_media_channel_cb,
+          NULL);
       return;
     }
 
-  DEBUG ("Let's try with an StreamedMedia channel");
-  g_error_free (error);
-  tp_account_channel_request_create_channel_async (streamed_media_req,
-      EMPATHY_AV_BUS_NAME, NULL,
-      create_streamed_media_channel_cb,
-      NULL);
+  show_call_error (error);
 }
 
 /* Try to request a Call channel and fallback to StreamedMedia if that fails */
@@ -174,8 +171,11 @@ call_new_with_streams (const gchar *contact,
     gboolean initial_video,
     gint64 timestamp)
 {
-  GHashTable *call_request, *streamed_media_request;
-  TpAccountChannelRequest *call_req, *streamed_media_req;
+  GHashTable *call_request;
+  TpAccountChannelRequest *call_req, *streamed_media_req = NULL;
+#ifdef HAVE_EMPATHY_AV
+  GHashTable *streamed_media_request;
+#endif
 
   /* Call */
   call_request = empathy_call_create_call_request (contact,
@@ -186,6 +186,7 @@ call_new_with_streams (const gchar *contact,
 
   g_hash_table_unref (call_request);
 
+#ifdef HAVE_EMPATHY_AV
   /* StreamedMedia */
   streamed_media_request = empathy_call_create_streamed_media_request (
       contact, initial_audio, initial_video);
@@ -195,44 +196,14 @@ call_new_with_streams (const gchar *contact,
       timestamp);
 
   g_hash_table_unref (streamed_media_request);
+#endif
 
   tp_account_channel_request_create_channel_async (call_req,
-      EMPATHY_CALL_BUS_NAME, NULL,
-      create_call_channel_cb,
-      streamed_media_req);
+      EMPATHY_CALL_BUS_NAME, NULL, create_call_channel_cb, streamed_media_req);
 
   g_object_unref (call_req);
 }
 
-#else /* HAVE_CALL */
-
-static void
-sm_new_with_streams (const gchar *contact,
-    TpAccount *account,
-    gboolean initial_audio,
-    gboolean initial_video,
-    gint64 timestamp)
-{
-  GHashTable *streamed_media_request;
-  TpAccountChannelRequest *streamed_media_req;
-
-  /* StreamedMedia */
-  streamed_media_request = empathy_call_create_streamed_media_request (
-      contact, initial_audio, initial_video);
-
-  streamed_media_req = tp_account_channel_request_new (account,
-      streamed_media_request,
-      timestamp);
-
-  g_hash_table_unref (streamed_media_request);
-
-  tp_account_channel_request_create_channel_async (streamed_media_req,
-      EMPATHY_AV_BUS_NAME, NULL, create_streamed_media_channel_cb, NULL);
-
-  g_object_unref (streamed_media_req);
-}
-#endif /* HAVE_CALL */
-
 void
 empathy_call_new_with_streams (const gchar *contact,
     TpAccount *account,
@@ -240,13 +211,8 @@ empathy_call_new_with_streams (const gchar *contact,
     gboolean initial_video,
     gint64 timestamp)
 {
-#ifdef HAVE_CALL
   call_new_with_streams (contact, account, initial_audio, initial_video,
       timestamp);
-#else
-  sm_new_with_streams (contact, account, initial_audio, initial_video,
-      timestamp);
-#endif
 }
 
 void
@@ -283,3 +249,85 @@ empathy_call_set_stream_properties (GstElement *element,
 
   g_object_unref (gsettings_call);
 }
+
+/* Copied from telepathy-yell call-channel.c */
+void
+empathy_call_channel_send_video (TpCallChannel *self,
+    gboolean send)
+{
+  GPtrArray *contents;
+  gboolean found = FALSE;
+  guint i;
+
+  g_return_if_fail (TP_IS_CALL_CHANNEL (self));
+
+  /* Loop over all the contents, if some of them a video set all their
+   * streams to sending, otherwise request a video channel in case we want to
+   * sent */
+  contents = tp_call_channel_get_contents (self);
+  for (i = 0 ; i < contents->len ; i++)
+    {
+      TpCallContent *content = g_ptr_array_index (contents, i);
+
+      if (tp_call_content_get_media_type (content) ==
+              TP_MEDIA_STREAM_TYPE_VIDEO)
+        {
+          GPtrArray *streams;
+          guint j;
+
+          found = TRUE;
+          streams = tp_call_content_get_streams (content);
+          for (j = 0; j < streams->len; j++)
+            {
+              TpCallStream *stream = g_ptr_array_index (streams, j);
+
+              tp_call_stream_set_sending_async (stream, send, NULL, NULL);
+            }
+        }
+    }
+
+  if (send && !found)
+    {
+      tp_call_channel_add_content_async (self, "video",
+          TP_MEDIA_STREAM_TYPE_VIDEO, TP_MEDIA_STREAM_DIRECTION_BIDIRECTIONAL,
+          NULL, NULL);
+    }
+}
+
+/* Copied from telepathy-yell call-channel.c */
+TpSendingState
+empathy_call_channel_get_video_state (TpCallChannel *self)
+{
+  TpSendingState result = TP_SENDING_STATE_NONE;
+  GPtrArray *contents;
+  guint i;
+
+  g_return_val_if_fail (TP_IS_CALL_CHANNEL (self), TP_SENDING_STATE_NONE);
+
+  contents = tp_call_channel_get_contents (self);
+  for (i = 0 ; i < contents->len ; i++)
+    {
+      TpCallContent *content = g_ptr_array_index (contents, i);
+
+      if (tp_call_content_get_media_type (content) ==
+              TP_MEDIA_STREAM_TYPE_VIDEO)
+        {
+          GPtrArray *streams;
+          guint j;
+
+          streams = tp_call_content_get_streams (content);
+          for (j = 0; j < streams->len; j++)
+            {
+              TpCallStream *stream = g_ptr_array_index (streams, j);
+              TpSendingState state;
+
+              state = tp_call_stream_get_local_sending_state (stream);
+              if (state != TP_SENDING_STATE_PENDING_STOP_SENDING &&
+                  state > result)
+                result = state;
+            }
+        }
+    }
+
+  return result;
+}
