@@ -132,13 +132,15 @@ typedef struct {
 	guint type;
 	EmpathyMessage *msg;
 	char *str;
+	gboolean should_highlight;
 } QueuedItem;
 
 static QueuedItem *
 queue_item (GQueue *queue,
 	    guint type,
 	    EmpathyMessage *msg,
-	    const char *str)
+	    const char *str,
+	    gboolean should_highlight)
 {
 	QueuedItem *item = g_slice_new0 (QueuedItem);
 
@@ -146,6 +148,7 @@ queue_item (GQueue *queue,
 	if (msg != NULL)
 		item->msg = g_object_ref (msg);
 	item->str = g_strdup (str);
+	item->should_highlight = should_highlight;
 
 	g_queue_push_tail (queue, item);
 
@@ -775,7 +778,8 @@ theme_adium_remove_all_focus_marks (EmpathyThemeAdium *theme)
 
 static void
 theme_adium_append_message (EmpathyChatView *view,
-			    EmpathyMessage  *msg)
+			    EmpathyMessage  *msg,
+			    gboolean         should_highlight)
 {
 	EmpathyThemeAdium     *theme = EMPATHY_THEME_ADIUM (view);
 	EmpathyThemeAdiumPriv *priv = GET_PRIV (theme);
@@ -797,7 +801,7 @@ theme_adium_append_message (EmpathyChatView *view,
 	gboolean               action;
 
 	if (priv->pages_loading != 0) {
-		queue_item (&priv->message_queue, QUEUED_MESSAGE, msg, NULL);
+		queue_item (&priv->message_queue, QUEUED_MESSAGE, msg, NULL, should_highlight);
 		return;
 	}
 
@@ -886,7 +890,7 @@ theme_adium_append_message (EmpathyChatView *view,
 	} else {
 		g_string_append (message_classes, " incoming");
 	}
-	if (empathy_message_should_highlight (msg)) {
+	if (should_highlight) {
 		g_string_append (message_classes, " mention");
 	}
 	if (empathy_message_get_tptype (msg) == TP_CHANNEL_TEXT_MESSAGE_TYPE_AUTO_REPLY) {
@@ -949,8 +953,6 @@ theme_adium_append_message (EmpathyChatView *view,
 		}
 	}
 
-	name_escaped = g_markup_escape_text (name, -1);
-
 	theme_adium_append_html (theme, func, html, body_escaped,
 				 avatar_filename, name_escaped, contact_id,
 				 service_name, message_classes->str,
@@ -977,7 +979,7 @@ theme_adium_append_event (EmpathyChatView *view,
 	gchar *str_escaped;
 
 	if (priv->pages_loading != 0) {
-		queue_item (&priv->message_queue, QUEUED_EVENT, NULL, str);
+		queue_item (&priv->message_queue, QUEUED_EVENT, NULL, str, FALSE);
 		return;
 	}
 
@@ -986,6 +988,14 @@ theme_adium_append_event (EmpathyChatView *view,
 	g_free (str_escaped);
 }
 
+static void
+theme_adium_append_event_markup (EmpathyChatView *view,
+				 const gchar     *markup_text,
+				 const gchar     *fallback_text)
+{
+	theme_adium_append_event_escaped (view, markup_text);
+}
+
 static void
 theme_adium_edit_message (EmpathyChatView *view,
 			  EmpathyMessage  *message)
@@ -999,7 +1009,7 @@ theme_adium_edit_message (EmpathyChatView *view,
 	GError *error = NULL;
 
 	if (priv->pages_loading != 0) {
-		queue_item (&priv->message_queue, QUEUED_EDIT, message, NULL);
+		queue_item (&priv->message_queue, QUEUED_EDIT, message, NULL, FALSE);
 		return;
 	}
 
@@ -1302,6 +1312,7 @@ theme_adium_iface_init (EmpathyChatViewIface *iface)
 {
 	iface->append_message = theme_adium_append_message;
 	iface->append_event = theme_adium_append_event;
+	iface->append_event_markup = theme_adium_append_event_markup;
 	iface->edit_message = theme_adium_edit_message;
 	iface->scroll = theme_adium_scroll;
 	iface->scroll_down = theme_adium_scroll_down;
@@ -1338,7 +1349,8 @@ theme_adium_load_finished_cb (WebKitWebView  *view,
 		switch (item->type)
 		{
 			case QUEUED_MESSAGE:
-				theme_adium_append_message (chat_view, item->msg);
+				theme_adium_append_message (chat_view, item->msg,
+					item->should_highlight);
 				break;
 
 			case QUEUED_EDIT:
@@ -1659,6 +1671,20 @@ empathy_theme_adium_set_variant (EmpathyThemeAdium *theme,
 	g_object_notify (G_OBJECT (theme), "variant");
 }
 
+void
+empathy_theme_adium_show_inspector (EmpathyThemeAdium *theme)
+{
+	WebKitWebView      *web_view = WEBKIT_WEB_VIEW (theme);
+	WebKitWebInspector *inspector;
+
+	g_object_set (G_OBJECT (webkit_web_view_get_settings (web_view)),
+		      "enable-developer-extras", TRUE,
+		      NULL);
+
+	inspector = webkit_web_view_get_inspector (web_view);
+	webkit_web_inspector_show (inspector);
+}
+
 gboolean
 empathy_adium_path_is_valid (const gchar *path)
 {
