@@ -141,7 +141,6 @@ validate_destination (NstPlugin *plugin,
                       gchar **error)
 {
   EmpathyContact *contact = NULL;
-  gboolean ret = TRUE;
 
   contact = get_selected_contact (contact_widget);
 
@@ -270,7 +269,7 @@ destroy (NstPlugin *plugin)
 
 static
 NstPluginInfo plugin_info = {
-  "im",
+  "empathy",
   "empathy",
   N_("Instant Message (Empathy)"),
   GETTEXT_PACKAGE,
