@@ -62,6 +62,7 @@ enum {
 typedef struct {
   GtkWidget *vbox;
   GtkWidget *treeview;
+  GtkWidget *scrolledwindow;
 
   GList *accounts;
   EmpathyImportApplication app_id;
@@ -91,25 +92,18 @@ import_widget_account_id_in_list (GList *accounts,
   return FALSE;
 }
 
+#define MAX_TREEVIEW_HEIGHT 300
+
 static void
-account_manager_prepared_cb (GObject *source_object,
-    GAsyncResult *result,
-    gpointer user_data)
+import_widget_add_accounts_to_model (EmpathyImportWidget *self)
 {
-  TpAccountManager *manager = TP_ACCOUNT_MANAGER (source_object);
-  EmpathyImportWidget *self = user_data;
+  TpAccountManager *manager;
   GtkTreeModel *model;
-  GtkTreeIter iter;
   GList *l;
   EmpathyImportWidgetPriv *priv = GET_PRIV (self);
-  GError *error = NULL;
+  gint min, natural;
 
-  if (!tp_proxy_prepare_finish (manager, result, &error))
-    {
-      DEBUG ("Failed to prepare account manager: %s", error->message);
-      g_error_free (error);
-      return;
-    }
+  manager = tp_account_manager_dup ();
 
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->treeview));
 
@@ -138,27 +132,20 @@ account_manager_prepared_cb (GObject *source_object,
 
       g_list_free (accounts);
 
-      gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-
-      gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+      gtk_list_store_insert_with_values (GTK_LIST_STORE (model), NULL, -1,
           COL_IMPORT, import,
           COL_PROTOCOL, data->protocol,
           COL_NAME, g_value_get_string (value),
           COL_SOURCE, data->source,
           COL_ACCOUNT_DATA, data,
           -1);
+
     }
-}
 
-static void
-import_widget_add_accounts_to_model (EmpathyImportWidget *self)
-{
-  TpAccountManager *manager;
-
-  manager = tp_account_manager_dup ();
-
-  tp_proxy_prepare_async (manager, NULL,
-      account_manager_prepared_cb, self);
+  /* Display as much rows as possible */
+  gtk_widget_get_preferred_height (priv->treeview, &min, &natural);
+  gtk_widget_set_size_request (priv->scrolledwindow, -1,
+      MIN (natural, MAX_TREEVIEW_HEIGHT));
 
   g_object_unref (manager);
 }
@@ -453,6 +440,7 @@ do_constructed (GObject *obj)
   gui = empathy_builder_get_file (filename,
       "widget_vbox", &priv->vbox,
       "treeview", &priv->treeview,
+      "scrolledwindow", &priv->scrolledwindow,
       NULL);
 
   g_free (filename);
