@@ -602,8 +602,7 @@ create_video_input (EmpathyStreamedMediaWindow *self)
 
   g_assert (priv->video_input == NULL);
   priv->video_input = empathy_video_src_new ();
-  gst_object_ref (priv->video_input);
-  gst_object_sink (priv->video_input);
+  gst_object_ref_sink (priv->video_input);
 }
 
 static void
@@ -613,8 +612,7 @@ create_audio_input (EmpathyStreamedMediaWindow *self)
 
   g_assert (priv->audio_input == NULL);
   priv->audio_input = empathy_audio_src_new ();
-  gst_object_ref (priv->audio_input);
-  gst_object_sink (priv->audio_input);
+  gst_object_ref_sink (priv->audio_input);
 
   tp_g_signal_connect_object (priv->audio_input, "peak-level-changed",
     G_CALLBACK (empathy_streamed_media_window_audio_input_level_changed_cb),
@@ -689,8 +687,7 @@ create_video_preview (EmpathyStreamedMediaWindow *self)
       priv->video_preview, TRUE, TRUE, 0);
 
   priv->video_tee = gst_element_factory_make ("tee", NULL);
-  gst_object_ref (priv->video_tee);
-  gst_object_sink (priv->video_tee);
+  gst_object_ref_sink (priv->video_tee);
 
   g_object_unref (bus);
 }
